import Database from 'better-sqlite3';
import { StorageProvider, StorageConfig } from '../types.js';
import { KnowledgeGraph } from '../../core.js';
/**
 * SQLite storage provider for lightweight deployments
 */
export declare class SQLiteStorageProvider implements StorageProvider {
    private config;
    private db;
    constructor(config: StorageConfig);
    /**
     * Initialize SQLite database and create tables
     */
    initialize(): Promise<void>;
    /**
     * Close database connection
     */
    close(): Promise<void>;
    /**
     * Health check for SQLite storage
     */
    healthCheck(): Promise<boolean>;
    /**
     * Load knowledge graph from SQLite database
     */
    loadGraph(project: string): Promise<KnowledgeGraph>;
    /**
     * Save knowledge graph to SQLite database
     */
    saveGraph(graph: KnowledgeGraph, project: string): Promise<void>;
    /**
     * Extract database file path from connection string
     */
    private extractDbPath;
    /**
     * Create database tables
     */
    private createTables;
    /**
     * Get SQLite database instance (for search strategies)
     */
    getSQLiteDatabase(): Database.Database | null;
}
//# sourceMappingURL=sqlite-storage.d.ts.map